// Sample data
const artworks = [
  { id: 1, title: 'Divine Light', artist: 'Sarah Blake', price: 1200, image: 'data:image/svg+xml,%3Csvg width="300" height="200" xmlns="http://www.w3.org/2000/svg"%3E%3Crect width="100%25" height="100%25" fill="%23e74c3c"/%3E%3C/svg%3E' },
  { id: 2, title: 'Sacred Space', artist: 'Michael Chen', price: 950, image: 'data:image/svg+xml,%3Csvg width="300" height="200" xmlns="http://www.w3.org/2000/svg"%3E%3Crect width="100%25" height="100%25" fill="%232c3e50"/%3E%3C/svg%3E' },
  // Add more artwork data
];

const events = [
  { id: 1, title: 'Spring Art Fair', date: '2024-04-15', venue: 'St. Mary\'s Church', available: 50 },
  { id: 2, title: 'Summer Exhibition', date: '2024-06-20', venue: 'Holy Trinity', available: 75 },
  // Add more event data
];

// Mobile menu functionality
const mobileMenuBtn = document.querySelector('.mobile-menu-btn');
const navLinks = document.querySelector('.nav-links');

mobileMenuBtn.addEventListener('click', () => {
  navLinks.classList.toggle('active');
});

// Gallery initialization
const galleryGrid = document.querySelector('.gallery-grid');
const artModal = document.getElementById('artModal');
const modalImage = document.getElementById('modalImage');
const modalTitle = document.getElementById('modalTitle');
const modalArtist = document.getElementById('modalArtist');
const modalPrice = document.getElementById('modalPrice');

artworks.forEach(artwork => {
  const artCard = document.createElement('div');
  artCard.className = 'art-card';
  artCard.innerHTML = `
    <img src="${artwork.image}" alt="${artwork.title}">
    <div class="art-info">
      <h3>${artwork.title}</h3>
      <p>${artwork.artist}</p>
      <p>£${artwork.price}</p>
    </div>
  `;
  
  artCard.addEventListener('click', () => {
    modalImage.src = artwork.image;
    modalImage.alt = artwork.title;
    modalTitle.textContent = artwork.title;
    modalArtist.textContent = artwork.artist;
    modalPrice.textContent = `£${artwork.price}`;
    artModal.showModal();
  });
  
  galleryGrid.appendChild(artCard);
});

// Events initialization
const eventsGrid = document.querySelector('.events-grid');
const bookingModal = document.getElementById('bookingModal');

events.forEach(event => {
  const eventCard = document.createElement('div');
  eventCard.className = 'event-card';
  eventCard.innerHTML = `
    <h3>${event.title}</h3>
    <p>Date: ${new Date(event.date).toLocaleDateString()}</p>
    <p>Venue: ${event.venue}</p>
    <p>Available Tickets: ${event.available}</p>
    <button onclick="openBooking(${event.id})">Book Now</button>
  `;
  eventsGrid.appendChild(eventCard);
});

// Modal handling
document.querySelectorAll('.close-modal').forEach(btn => {
  btn.addEventListener('click', () => {
    artModal.close();
    bookingModal.close();
  });
});

// Form submissions
document.getElementById('offerForm').addEventListener('submit', (e) => {
  e.preventDefault();
  // Handle offer submission
  alert('Offer submitted successfully!');
  artModal.close();
});

document.getElementById('bookingForm').addEventListener('submit', (e) => {
  e.preventDefault();
  // Handle booking submission
  alert('Booking confirmed!');
  bookingModal.close();
});

function openBooking(eventId) {
  bookingModal.showModal();
}